@@ -1,5 +1,4 @@
 from datetime import datetime
-from typing import List
 from typing import Optional
 from typing import Union
 
@@ -25,14 +24,14 @@ class Journal:
         self.date: datetime = datetime.fromtimestamp(0)
         self.author: UserPartial = UserPartial()
         self.content: str = ""
-        self.mentions: List[str] = []
+        self.mentions: list[str] = []
 
         self.parse()
 
     def __iter__(self):
         yield "id", self.id
         yield "title", self.title
-        yield "date", self.date.timetuple()
+        yield "date", self.date
         yield "author", dict(self.author)
         yield "content", self.content
         yield "mentions", self.mentions
